@@ -48,13 +48,12 @@ def get_optimal_train_size(
     return train_size
 
 
-def get_optimal_batch_size(nb_vectors: int, vec_dim: int, current_memory_available: str) -> int:
-    """compute optimal batch size to use the RAM at its full potential"""
+def get_optimal_batch_size(vec_dim: int, current_memory_available: str) -> int:
+    """compute optimal batch size to use the RAM at its full potential for adding vectors"""
 
-    total_size = nb_vectors * vec_dim * 4  # in bytes
     memory = cast_memory_to_bytes(current_memory_available)
 
-    batch_size = int(0.5 * total_size / memory)
+    batch_size = int(min(memory, 10 ** 9) / (vec_dim * 4))  # using more than 1GB of ram is not faster here
 
     return batch_size
 
